@@ -1,4 +1,4 @@
-// $Id: /mirror/openjsan/users/theory/Test.Simple/trunk/lib/Test/More.js 1950 2008-08-20T06:40:51.750920Z ingy  $
+// $Id$
 
 /*global JSAN, Test */
 
@@ -24,7 +24,7 @@ Test.More.EXPORT = [
     'beginAsync', 'endAsync'
 ];
 Test.More.EXPORT_TAGS = { ':all': Test.More.EXPORT };
-Test.More.VERSION     = '0.28';
+Test.More.VERSION     = '0.29';
 
 Test.More.ShowDiag = true;
 Test.Builder.DNE = { dne: 'Does not exist' };
@@ -63,18 +63,20 @@ Test.More.cmpOK = function (got, op, expect, desc) {
     return Test.More.Test.cmpOK(got, op, expect, desc);
 };
 
-Test.More.canOK = function (proto) {
-    var ok;
+Test.More.canOK = function (classProtoInstance) {
+    var ok, proto, clas, instance = {};
     // Get the class name and the prototype.
     var clas;
-    if (typeof proto == 'string') {
+    if (typeof classProtoInstance == 'string') {
         // We just have a class name.
-        clas = proto;
-        proto = eval(clas + '.prototype');
+        clas  = classProtoInstance;
+        proto = eval( clas + '.prototype' ) || {};
+        instance = eval( clas ) || {};
     } else {
         // We have an object or something that can be converted to an object.
-        clas = Test.Builder.typeOf(proto);
-        proto = proto.constructor.prototype;
+        clas     = Test.Builder.typeOf(classProtoInstance);
+        proto    = classProtoInstance.constructor.prototype;
+        instance = classProtoInstance;
     }
 
     // Make sure they passed some method names for us to check.
@@ -87,7 +89,11 @@ Test.More.canOK = function (proto) {
     var nok = [];
     for (var i = 1; i < arguments.length; i++) {
         var method = arguments[i];
-        if (typeof proto[method] != 'function') nok.push(method);
+        if (   typeof proto[method]    != 'function' 
+            && typeof instance[method] != 'function' )
+        {
+            nok.push(method);
+        }
     }
 
     // There's no can() method in JavaScript, but what the hell!
